<?php
    /**
     * Reporte de Pagos por Usuario, Condominio y Departamento.
     */
    
    // Conexión a la base de datos
    $conexion = new mysqli("localhost", "root", "gabino22", "condominios");
    if ($conexion->connect_error) {
        die("Error de conexión: " . $conexion->connect_error);
    }

    // Consulta para obtener el total de pagos por inquilino, agrupado por concepto, condominio y departamento
    $sql = "SELECT inquilinos.nombre AS inquilino, condominios.condominio_nombre AS condominio, departamento.numero AS departamento, 
                   cat_servicios.nombre_servicio AS concepto, SUM(pagos.monto) AS total
            FROM pagos
            JOIN inquilinos ON pagos.id_inquilino = inquilinos.id
            JOIN departamento ON departamento.id_inquilino = inquilinos.id
            JOIN condominios ON condominios.id = departamento.id_condominio
            JOIN cat_servicios ON pagos.id_servicio = cat_servicios.id
            GROUP BY inquilinos.nombre, condominios.condominio_nombre, departamento.numero, cat_servicios.nombre_servicio";
    
    $result = $conexion->query($sql);

    // Preparar los datos para Chart.js
    $data = [];
    while ($row = $result->fetch_assoc()) {
        $inquilino_key = $row['inquilino'] . ' (' . $row['condominio'] . ', Dpto: ' . $row['departamento'] . ')';
        $data[$inquilino_key]['conceptos'][] = $row['concepto'];
        $data[$inquilino_key]['totales'][] = $row['total'];
    }

    // Convertimos los datos en formato JSON para pasarlos a Chart.js
    $data_json = json_encode($data);

    // Cerramos la conexión
    $conexion->close();
?>
<!DOCTYPE html>
<html lang="es">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reporte de Pagos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script> <!-- Cargamos Chart.js -->
</head>

<body>

    <!-- Navbar superior -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
    </nav>

    <!-- Sidebar -->
    <?php include("sidebar.php"); ?>

    <!-- Contenido principal -->
    <div class="content container mt-4">
        <h1>Reporte de Pagos por Usuario</h1>

        <!-- Sección de gráficos -->
        <div class="row">
            <?php foreach ($data as $inquilino => $info): ?>
                <div class="col-md-6 mb-4">
                    <div class="card">
                        <div class="card-header bg-primary text-white">
                            Pagos de <?php echo $inquilino; ?>
                        </div>
                        <div class="card-body">
                            <canvas id="chart_<?php echo md5($inquilino); ?>"></canvas> <!-- Contenedor del gráfico -->
                        </div>
                    </div>
                </div>
                <script>
                    // Paleta de colores para las gráficas
                    var backgroundColors = [
                        'rgba(54, 162, 235, 0.2)', 'rgba(255, 99, 132, 0.2)', 'rgba(255, 206, 86, 0.2)', 
                        'rgba(75, 192, 192, 0.2)', 'rgba(153, 102, 255, 0.2)', 'rgba(255, 159, 64, 0.2)',
                        'rgba(199, 199, 199, 0.2)', 'rgba(83, 102, 255, 0.2)', 'rgba(200, 162, 135, 0.2)', 
                        'rgba(100, 132, 235, 0.2)'
                    ];

                    var borderColors = [
                        'rgba(54, 162, 235, 1)', 'rgba(255, 99, 132, 1)', 'rgba(255, 206, 86, 1)', 
                        'rgba(75, 192, 192, 1)', 'rgba(153, 102, 255, 1)', 'rgba(255, 159, 64, 1)',
                        'rgba(199, 199, 199, 1)', 'rgba(83, 102, 255, 1)', 'rgba(200, 162, 135, 1)', 
                        'rgba(100, 132, 235, 1)'
                    ];

                    // Crear gráfica para cada inquilino
                    var ctx = document.getElementById('chart_<?php echo md5($inquilino); ?>').getContext('2d');
                    var chart = new Chart(ctx, {
                        type: 'bar',
                        data: {
                            labels: <?php echo json_encode($info['conceptos']); ?>, // Conceptos
                            datasets: [{
                                label: 'Total de Pagos',
                                data: <?php echo json_encode($info['totales']); ?>, // Totales
                                backgroundColor: backgroundColors.slice(0, <?php echo count($info['conceptos']); ?>),
                                borderColor: borderColors.slice(0, <?php echo count($info['conceptos']); ?>),
                                borderWidth: 1
                            }]
                        },
                        options: {
                            scales: {
                                y: {
                                    beginAtZero: true
                                }
                            },
                            plugins: {
                                legend: {
                                    display: true,
                                    position: 'top'
                                }
                            }
                        }
                    });
                </script>
            <?php endforeach; ?>
        </div>
    </div>

    <!-- Footer -->
    <?php include("footer.php"); ?>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>
