<?php
    /**
     * Reporte personalizado de pagos por inquilino y rango de fechas, mostrando todos los conceptos en una tabla y una gráfica.
     */
    
    // Conexión a la base de datos
    $conexion = new mysqli("localhost", "root", "gabino22", "condominios");
    if ($conexion->connect_error) {
        die("Error de conexión: " . $conexion->connect_error);
    }

    // Consulta para obtener los inquilinos disponibles
    $inquilinos_sql = "SELECT id, nombre FROM inquilinos";
    $inquilinos_result = $conexion->query($inquilinos_sql);

    // Variables para almacenar los datos seleccionados
    $inquilino_seleccionado = isset($_POST['inquilino']) ? $_POST['inquilino'] : '';
    $fecha_inicio = isset($_POST['fecha_inicio']) ? $_POST['fecha_inicio'] : '';
    $fecha_fin = isset($_POST['fecha_fin']) ? $_POST['fecha_fin'] : '';
    $inquilino_info = [];

    // Si el formulario ha sido enviado, obtenemos los detalles del inquilino, edificio, y ubicación
    if ($inquilino_seleccionado) {
        $inquilino_info_sql = "
            SELECT inquilinos.nombre AS inquilino, departamento.numero AS departamento, condominios.condominio_nombre AS edificio, inmueble.calle AS ubicacion
            FROM inquilinos
            JOIN departamento ON departamento.id_inquilino = inquilinos.id
            JOIN condominios ON condominios.id = departamento.id_condominio
            JOIN inmueble ON inmueble.id = condominios.id_inmueble
            WHERE inquilinos.id = '$inquilino_seleccionado'";
        
        $inquilino_info_result = $conexion->query($inquilino_info_sql);
        $inquilino_info = $inquilino_info_result->fetch_assoc();
    }

    // Preparar la consulta SQL si se envió el formulario
    if ($inquilino_seleccionado && $fecha_inicio && $fecha_fin) {
        $sql = "SELECT inquilinos.nombre AS inquilino, cat_servicios.nombre_servicio AS concepto, SUM(pagos.monto) AS total
                FROM pagos
                JOIN inquilinos ON pagos.id_inquilino = inquilinos.id
                JOIN cat_servicios ON pagos.id_servicio = cat_servicios.id
                WHERE pagos.id_inquilino = '$inquilino_seleccionado'
                AND pagos.fecha_pago BETWEEN '$fecha_inicio' AND '$fecha_fin'
                GROUP BY cat_servicios.nombre_servicio";
        
        $result = $conexion->query($sql);

        // Preparar los datos para Chart.js y la tabla
        $conceptos = [];
        $totales = [];
        $tabla_datos = '';
        while ($row = $result->fetch_assoc()) {
            $conceptos[] = $row['concepto'];
            $totales[] = $row['total'];
            // Agregamos cada fila a la tabla
            $tabla_datos .= "<tr><td>{$row['concepto']}</td><td>\${$row['total']}</td></tr>";
        }
        
        $conceptos_json = json_encode($conceptos);
        $totales_json = json_encode($totales);
    }

    // Cerramos la conexión
    $conexion->close();
?>
<!DOCTYPE html>
<html lang="es">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reporte Personalizado de Pagos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script> <!-- Cargamos Chart.js -->
    <style>
        .chart-container {
            width: 70%;  /* Ajustamos el tamaño al 70% del tamaño original */
            height: 70%; /* Reducimos la altura al 70% del tamaño original */
            margin: 0 auto; /* Centramos el contenedor */
        }
    </style>
</head>

<body>

    <!-- Navbar superior -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
    </nav>

    <!-- Sidebar -->
    <?php include("sidebar.php"); ?>

    <!-- Contenido principal -->
    <div class="content container mt-4">
        <h1>Generar Reporte de Pagos por Inquilino y Rango de Fechas</h1>

        <!-- Formulario de selección de inquilino y fechas -->
        <form method="POST" action="">
            <div class="row mb-3">
                <div class="col-md-4">
                    <label for="inquilino" class="form-label">Seleccionar Inquilino:</label>
                    <select class="form-select" id="inquilino" name="inquilino" required>
                        <option value="">Seleccionar</option>
                        <?php while ($row = $inquilinos_result->fetch_assoc()): ?>
                            <option value="<?php echo $row['id']; ?>" <?php echo ($row['id'] == $inquilino_seleccionado) ? 'selected' : ''; ?>>
                                <?php echo $row['nombre']; ?>
                            </option>
                        <?php endwhile; ?>
                    </select>
                </div>

                <div class="col-md-4">
                    <label for="fecha_inicio" class="form-label">Fecha de Inicio:</label>
                    <input type="date" class="form-control" id="fecha_inicio" name="fecha_inicio" value="<?php echo $fecha_inicio; ?>" required>
                </div>

                <div class="col-md-4">
                    <label for="fecha_fin" class="form-label">Fecha de Fin:</label>
                    <input type="date" class="form-control" id="fecha_fin" name="fecha_fin" value="<?php echo $fecha_fin; ?>" required>
                </div>
            </div>

            <button type="submit" class="btn btn-primary">Generar Reporte</button>
        </form>

        <!-- Mostrar información del inquilino si se selecciona -->
        <?php if (!empty($inquilino_info)): ?>
            <div class="row mt-4">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-header bg-info text-white">
                            Información del Inquilino
                        </div>
                        <div class="card-body">
                            <p><strong>Inquilino:</strong> <?php echo $inquilino_info['inquilino']; ?></p>
                            <p><strong>Departamento:</strong> <?php echo $inquilino_info['departamento']; ?></p>
                            <p><strong>Edificio:</strong> <?php echo $inquilino_info['edificio']; ?></p>
                            <p><strong>Ubicación (Inmueble):</strong> <?php echo $inquilino_info['ubicacion']; ?></p>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <!-- Tabla de datos si hay resultados -->
        <?php if (isset($tabla_datos) && $tabla_datos !== ''): ?>
            <div class="row mt-5">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-header bg-primary text-white">
                            Detalle de Pagos del Inquilino Seleccionado
                        </div>
                        <div class="card-body">
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>Concepto</th>
                                        <th>Total Pagado</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php echo $tabla_datos; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <!-- Gráfica si hay datos -->
        <?php if (isset($conceptos_json) && isset($totales_json)): ?>
            <div class="row mt-5">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-header bg-primary text-white">
                            Gráfica de Pagos del Inquilino Seleccionado
                        </div>
                        <div class="card-body">
                            <div class="chart-container">
                                <canvas id="chart_pagos"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <script>
                var ctx = document.getElementById('chart_pagos').getContext('2d');
                var chart = new Chart(ctx, {
                    type: 'bar',
                    data: {
                        labels: <?php echo $conceptos_json; ?>, // Conceptos
                        datasets: [{
                            label: 'Total de Pagos',
                            data: <?php echo $totales_json; ?>, // Totales
                            backgroundColor: [
                                'rgba(54, 162, 235, 0.2)', 'rgba(255, 99, 132, 0.2)', 'rgba(255, 206, 86, 0.2)', 
                                'rgba(75, 192, 192, 0.2)', 'rgba(153, 102, 255, 0.2)', 'rgba(255, 159, 64, 0.2)',
                                'rgba(199, 199, 199, 0.2)', 'rgba(83, 102, 255, 0.2)', 'rgba(200, 162, 135, 0.2)', 
                                'rgba(100, 132, 235, 0.2)'
                            ],
                            borderColor: [
                                'rgba(54, 162, 235, 1)', 'rgba(255, 99, 132, 1)', 'rgba(255, 206, 86, 1)', 
                                'rgba(75, 192, 192, 1)', 'rgba(153, 102, 255, 1)', 'rgba(255, 159, 64, 1)',
                                'rgba(199, 199, 199, 1)', 'rgba(83, 102, 255, 1)', 'rgba(200, 162, 135, 1)', 
                                'rgba(100, 132, 235, 1)'
                            ],
                            borderWidth: 2
                        }]
                    },
                    options: {
                        scales: {
                            y: {
                                beginAtZero: true
                            }
                        },
                        plugins: {
                            legend: {
                                display: true,
                                position: 'top'
                            }
                        }
                    }
                });
            </script>
        <?php endif; ?>
    </div>

    <!-- Footer -->
    <?php include("footer.php"); ?>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>
